@@ -29,3 +29,6 @@ def turn_left(a):
 
 def turn_right(a):
   turtle.right(a)
+
+def startdraw():
+  turtle.screensize(500,500)
